# Installation

## Prerequisites

- [Git](https://git-scm.com/)
- [NodeJS](https://nodejs.org)

## Install tools

1. `sudo npm install --location=global npm@latest`
2. `sudo npm install --location=global yarn@latest`

## Build

```shell
# Clone repo locally
git clone https://repo1.dso.mil/platform-one/big-bang/apps/sandbox/landscape.git
cd landscape

# Setup Github API key with no permissions (https://github.com/settings/tokens)
export GITHUB_KEY=myGithubAPIKey

# Download node module dependencies and builds site
# NOTE: It is normal to see twitter fetching errors since we did not
# setup a Twitter API key and aren't using the "Latest Tweet" field
npm install  # This will download dependencies and patch them
npm run build # This will update the data and build the website

# Run development web server
npm start

# Navigate to http://localhost:8080 to view landscape
```

## Updating data manually

> This is done automatically if you are running `npm run build`.  The following instructions are how to update the data manually.

After making your changes to `landscape.yml`, run `npm run fetch` to fetch any needed data and generate [processed_landscape.yml](processed_landscape.yml) and [data.json](data.json).

`npm run fetch` runs in 4 modes of increasingly aggressive downloading, with a default to easy. Reading data from the cache (meaning from `processed_landscape.yml`) means that no new data is fetched if the project/product already exists. The modes are:

| Data cached            | easy   | medium   | hard   | complete   |
|------------------------|--------|----------|--------|------------|
| **GitHub basic stats** | true   | false    | false  | false      |
| **GitHub start dates** | true   | true     | false  | false      |
| **Image data**         | true   | true     | true   | false      |

- **Easy** mode just fetches any data needed for new projects/products.
- **Medium** fetches basic GitHub data for all projects/products.
- **Hard** also fetches GitHub start dates. These should not change so this should not be necessary.
- **Complete** also re-fetches all images. This is problematic because images tend to become unavailable (404) over time, even though the local cache is fine.

To run a different mode, set the environmental variable `LEVEL`.  For example, to run hard mode, run `LEVEL=hard npm run fetch`.

Hard and complete modes should be unnecessary except in cases of possible data corruption. Even then, it's better to just delete any problematic entries from `processed_landscape.yml` and easy mode will recreate them with up-to-date information.

### Adding a custom image

If you can't find the right logo on the web, you can create a custom one and host it in this repo:

1. Save the logo to `hosted_logos/`, for example, `hosted_logos/apex.svg`. Use lowercase spinal case (i.e. hyphens) for the name.
1. Update `landscape.yml`, for example, `logo: apex.svg`. The location `./hosted_logos` will be added as a prefix automatically to the beginning of the file name.
1. If you've updated the local logo since a previous commit, you need to delete the cached version in `./cached_logos/`.
1. Update `processed_landscape.yml` by navigating to `node_modules/interactive-landscape`
    - $ cd node_modules/interactive-landscape
    - $ export PROJECT_PATH=../..
    - $ touch yarn.lock
    - $ yarn set version stable
    - $ yarn install
    - $ npm run fetchAll
1. Verify `processed_landscape.yaml` was updated with the new information
1. Build the static HTML files once more with:
    - $ cd ../../
    - $ npm run build
1. Run your new changes 
    - $ npm start
1. Navigate to localhost:8080 and verify the image was updated
1. Commit and push.

*These instructions have been tested and work on MacOS and Linux. Some issues have been reported while using WSL.*

### Testing Content Security Policies

The `http-server` module used for development does not have the ability to add custom headers to test Content Security Policies (CSP).  Instead, use docker to deploy a Nginx server using special configuration (`nginx.conf`).

``` shell
# Run Nginx serving the files from /dist and using the nginx.conf configuration
docker run -it --rm -p 8080:8080 -v $PWD/dist:/var/www/bigbang -v $PWD/nginx.conf:/etc/nginx/conf.d/bigbang.conf nginx
```

Now you can access your website at `http://localhost:8080`.  In your browser, y ou can see violations by opening the developer tools and looking at the console.
