# Modifications

The upstream interactive landscape uses an API for filtering.  In order to make this a static site, several changes are required in order to replace this API.  This document covers the details of the modifications required to convert the website to a static website.

## Patching

[patch-package](https://www.npmjs.com/package/patch-package) is used to create a patch file and apply that patch during the build phase of the website.  To create patches, simply modify a dependency by hand, then run `npx patch-package <dependency name>`.  The patch will be placed in the `patches` folder and automatically used in future builds of the website.

## Interactive Landscape

The following changes are patched into `interactive-landscape`.  For details see the `patches/interactive-landscape*.patch` file.

- Add client-side filtering
  - `tools/renderitems.js` - Load `jquery.min.js` script
  - `tools/prepareLandscape.js` - Copy `node_modules/jquery/dist/jquery.min.js` script to `/dist`
  - `src/script.js`
    - Changed `handlePopupItemClick(itemEl)` to asynchronous
    - Appended `handlePopupItemClick(itemEl)` with call to `generateJSON`
    - Added async functions `getItems` and `generateJSON`
    - Replaced calls to `fetchApiData` with `generateJSON`
- Fix link for documentation
  - `src/components/HomePageRenderer.js` - moved `</div>` above the sidebar event.
- Disable sorting and grouping in filtering (not working)
  - `src/style.css` - add `select-disabled` class
  - `src/script.js` - add `select-disabled` class to `sort` and `grouping` items.
- Remove export to CSV (not working)
  - `src/components/HomePageRenderer.js` - removed link to CSV download.
- Update version to date/time
  - `src/components/HomePageRenderer.js` - Changed `version` to current date/time.
  - `tools/renderItems.js` - Changed `version` to current date/time.
- Remove iframeResizer.contentWindow.map (non existent)
  - `tools/renderItems.js` - Added regex to filter out map before writing to `/dist`
- Remove twitter (content security policy violation)
  - `src/embedded-script.js` - Removed `twttr` references
  - `src/script.js` - Removed `twttr` references
  - `src/components/ItemDialogContentRenderer.js` - Removed twitter button
- Convert inline fonts to loaded (content security policy violation)
  - `tools/renderItems.js` - Changed inline font load to load from Google's static font site.
- Convert inline styles to style blocks (content security policy violation)
  - Various - `style=` replaced with a `<style></style>` block and `class=`.  All styles created with unique names.
  - `src/script.js` - On init, remove `hidden` class and add `style.display = "none"` to `.select-popup`, `.modal`, `#guide-page` and `#home`
- Add `nonce` (content security policy violation) to `<script>` and `<style>` blocks.
  - `src/script.js`
    - Add function to dynamically replace nonce of fetched scripts/styles to match document before applying to objects
    - Replaced calls to `text()` with call to nonce replacement function
- Replace references to "Landscape" to "Universe"
  - Patched Universe/Guide buttons
  - Patched Guide Header
- Added `skip_twitter` option to skip over twitter updates during build.
  - `tools/addExternalInfo.js` - Conditional added to console output and fetching routines
  - `tools/generateJson.js` - Conditional added around generating .json for twitter
  - `tools/apiClients.js` - Check for TWITTER_KEY removed
- Remove footer referencing crunchdata
  - `src/components/HomePageRenderer.js` - deleted crunchdata footer HTML

## Known issues

- Exporting to CSV provides a blank .txt file.  This has been disabled.
- Sorting and grouping are not yet working and have been disabled
- .pdf and .png files are not working in the pipeline yet
