## Introduction

In this guide, we’ll breakdown the Big Bang Universe's layers and categories.

![Big Bang Universe](https://universe.bigbang.dso.mil/images/landscape_preview.png "Big Bang Universe")

> **INFOBOX**
>
> When looking at the universe, you'll note a few distinctions:
>
> * *Projects in large boxes* have been assigned a maturity level.
> * *Projects with white backgrounds* are open source projects.
> * *Products with gray backgrounds* are proprietary products.
>
> Please note that new projects are continuously becoming part of Big Bang so
> always refer to the actual universe.

## Layers

### Core

[View Cards in Category](/card-mode?category=core)

The Core layer encompasses packages that make up the functionality required for a cluster to be called "Big Bang".  One or more packages from each category must be enabled.
You'll find packages to manage networking, security, policies, monitoring, and logging in this layer.  All of these packages are included in Big Bang's main Helm chart.  Recommended packages are automatically enabled.

### Addons

[View Cards in Category](/card-mode?category=addons)

The AddOn layer includes optional packages that are commonly used by Big Bang clusters.  All of them are included in Big Bang's main Helm chart, but are turned off by default.  Depending on your use case, you can enable the packages that you need.
You'll find a variety of packages covering storage, backup, security, collaboration, static analysis, and more.

### Community

[View Cards in Category](/card-mode?category=community)

The Community layer holds packages that are not included in the Big Bang Helm chart, but are still compatible with Big Bang.  These packages have all of the integration required to use Big Bang components and have gone through an evaluation by the Technical Oversite Committee (TOC).  Use these to extend Big Bang for desired functionality.

## Categories

### Service Mesh

[View Cards in Category](/card-mode?category=service-mesh)

#### What it is

Service meshes manage traffic (i.e. communication) between services. They enable platform teams
to add reliability, observability, and security features uniformly across all services running
within a cluster without requiring any code changes.

#### Key Features

* Network traffic control
* Traffic observability
* End-to-end TLS encryption
* Load Balancing
* Circuit Breakers
* Traffic splitting (e.g canary, blue/green)
* Network security

#### Additional Info

* [Service mesh interface specification](https://smi-spec.io/)
* [Service mesh wiki](https://en.wikipedia.org/wiki/Service_mesh)

### Monitoring

[View Cards in Category](/card-mode?category=monitoring)

#### What it is

Monitoring is a quantitative reporting mechanism that helps with proactive management of clusters.  The most common metrics include CPU, memory, and network use.  The monitoring stack includes metrics collection, alerting, and display.

#### Key Features

* Time Series Metrics
* Alerting
* Telemetry
* Dashboards

#### Additional Info

* [Monitoring Kubernetes in Production](https://sysdig.com/blog/monitoring-kubernetes/)
* [Kubernetes Monitoring: Best Practices, Methods, and Existing Solutions](https://logz.io/blog/kubernetes-monitoring/)

### Logging

[View Cards in Category](/card-mode?category=logging)

#### What it is

Logging is a way to collect and analyze verbose information from cluster containers.  The logging stack will provide a consolidated and persistent view of logs across the entire cluster.  It may also provide the ability to analyze the logs for specific events.

#### Key Features

* Event Recording
* Pod Log Capture
* Log Analytics

### Additional Info

* [Logging Architecture](https://kubernetes.io/docs/concepts/cluster-administration/logging/)
* [A Practical Guide to Kubernetes Logging](https://logz.io/blog/a-practical-guide-to-kubernetes-logging/)

### Tracing

[View Cards in Category](/card-mode?category=tracing)

#### What it is

Distributed tracing packages holistically analyze network traffic between operations in a cluster.  Flows, from request to response, can be analyzed for various attributes, like errors, or metrics, like latency.

#### Key Features

* Distributed transaction collection
* Performance analysis tools
* Troubleshooting tools

#### Additional Info

* [Distributed tracing: A Complete Guide](https://lightstep.com/distributed-tracing)

### Security & Compliance

[View Cards in Category](/card-mode?category=security-compliance)

#### What it is

Security and Compliance packages provide features to detect or prevent implementations that could lead to unauthorized exchange of information.

#### Key Features

* Vulnerability scanning
* Artifact signing or signature verification
* Policy enforcement
* Auditing
* Runtime detection or prevention of unusual activity
* Incident response

#### Additional Info

* [Implement Continuos Compliance for Kubernetes](https://www.infosecurity-magazine.com/opinions/continuous-compliance-kubernetes/)
* [NIST Vulnerability Database](https://nvd.nist.gov/vuln)
* [Kubernetes CIS Benchmark](https://www.cisecurity.org/benchmark/kubernetes)
* [Kubernetes STIG](https://stigviewer.com/stig/kubernetes)
* [Kubernetes Hardening Guide](https://media.defense.gov/2021/Aug/03/2002820425/-1/-1/0/CTR_Kubernetes_Hardening_Guidance_1.1_20220315.PDF)
* [NIST 800-53](https://nvlpubs.nist.gov/nistpubs/SpecialPublications/NIST.SP.800-53r5.pdf)

### Storage

[View Cards in Category](/card-mode?category=storage)

#### What it is

This category contains packages that provide long-term or temporary storage of data for Pods in the cluster.  Storage can be accessed by using volumes or through an API.  The packages here are in-cluster equivalents to cloud provided storage.

#### Key Features

* File, block, or object storage
* Caching
* Scaling and distribution
* Access control to data

#### Additional Info

* [Kubernetes Storage Types](https://stackoverflow.com/a/65869167/16441287)

### Backup & Restore

[View Cards in Category](/card-mode?category=backup-restore)

#### What it is

Backup and restore packages not only provide snapshots of persistent data, but can also save entire cluster and application configurations.  The backups can be safely secured in cloud storage and restored on demand.

#### Key Features

* Cluster / application resource backup and restore
* Persistent volume backup and restore
* Disaster recovery
* Cluster repair, migration, or replication
* Encryption at Rest
* Backup strategies (e.g. incremental, differential)

#### Additional Info

* [How to Backup Kubernetes](https://www.baculasystems.com/blog/kubernetes-backup/)
* [7 Common Kubernetes Backup and Recovery Mistakes](https://rafay.co/the-kubernetes-current/7-common-kubernetes-backup-recovery-mistakes/)

### Continuous Integration & Delivery

[View Cards in Category](/card-mode?category=continuous-integration-delivery)

#### What it is

Continuous integration and delivery tools are used to expedite software delivery into production.  The goal of these tools is to automate the steps between software commitment through deployment.  Often these tools include a rich set of software development life cycle features, like bug tracking, or work planning.

#### Key Features

* Automated build and delivery
* Automated deployment
* Automated test
* Code repository
* Issue tracking
* Milestone planning
* Releases

#### Additional Info

* [Kubernetes CI/CD Pipelines: What, Why, and How](https://ubuntu.com/blog/kubernetes-ci-cd-pipelines-what-why-and-how)
* [CI/CD Pipelines with Kubernetes: Best Practices and Tools](https://www.containiq.com/post/cicd-pipelines-with-kubernetes)

### Registry

[View Cards in Category](/card-mode?category=registry)

#### What it is

For Kubernetes, registries are used to store, share, and manage artifacts, like Helm charts or container images, needed for deploying resources.

#### Key Features

* Artifact storage (e.g OCI)
* Static vulnerability scanning
* Artifact hash
* Access control to artifacts

#### Additional Info

* [What is a container registry](https://www.redhat.com/en/topics/cloud-native-apps/what-is-a-container-registry)

### Access Control

[View Cards in Category](/card-mode?category=access-control)

#### What it is

Access control packages help to secure services running in your Kubernetes cluster by providing users (or other services) access to only what they need.

#### Key Features

* Authentication, authorization, and accounting
* Identify Provider
* Role based access control
* Single-sign On (SSO)

#### Additional Info

* [Authentication, Authorization, and Accounting](https://www.techtarget.com/searchsecurity/definition/authentication-authorization-and-accounting)
* [Identity Providing](https://en.wikipedia.org/wiki/Identity_provider)
* [Least Privilege](https://www.cisa.gov/uscert/bsi/articles/knowledge/principles/least-privilege)

### Key Management

[View Cards in Category](/card-mode?category=key-management)

#### What it is

When administrating a Kubernetes cluster, sensitive data must be securely stored and protected from unauthorized access.  Traditionally, key management involved safely storing private encryption keys.  But in modern Key Management Services (KMS), storage of credentials, certificates, licenses, etc. are more common.

#### Key Features

* Persistent storage of sensitive data
* Granular access control
* Encryption at rest
* FIPS 140-2 compliance

#### Additional Info

* [Using a KMS provider for data encryption](https://kubernetes.io/docs/tasks/administer-cluster/kms-provider/)

### Collaboration

[View Cards in Category](/card-mode?category=collaboration)

#### What it is

Collaboration packages center around improving communication for communities.

#### Key Features

* Chat
* Video Conferencing
* Whiteboard
* Calendars
* Notifications
* Search
* Content Management
* Workflows

#### Additional Info

* [Collaboration Tool Wiki](https://en.wikipedia.org/wiki/Collaboration_tool)
* [Collaboration 101: Your Essential Guide](https://www.uctoday.com/collaboration/collaboration-101-your-essential-guide/)

### Software Development

[View Cards in Category](/card-mode?category=software-development)

#### What it is

Software developers utilize these packages to be more productive.  Focus is on improving the efficiency and quality of code being created.

#### Key Features

* Interactive Development Environments (IDE)
* Code analysis for best practices, vulnerabilities, and/or test coverage
* Compilers and linkers
* Test frameworks

#### Additional Info

* [What is an IDE](https://www.redhat.com/en/topics/middleware/what-is-ide)
* [Static Code Analysis](https://owasp.org/www-community/controls/Static_Code_Analysis)

### Virtual Machines

[View Cards in Category](/card-mode?category=virtual-machines)

#### What it is

In order to run services that have not been containerized in Kubernetes, you must run them in a Virtual Machine.  The Virtual Machine can then be managed by Kubernetes.  This category covers packages that assist with lifecycle management of Virtual Machines in Kubernetes clusters.

#### Key Features

* VM orchestration
* VM networking

#### Additional Info

* [You've Got Virtual Machines in my Container Platform!](https://www.redhat.com/en/blog/youve-got-virtual-machines-my-container-platform-argument-running-vms-kubernetes)
